==> thymeleaf-2.1.4.RELEASE-sources.jar: org/thymeleaf/exceptions/TemplateOutputException.java <==
/*
 * =============================================================================
 * 
 *   Copyright (c) 2011-2014, The THYMELEAF team (http://www.thymeleaf.org)
 * 
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * 
 * =============================================================================
 */
package org.thymeleaf.exceptions;

/**
 * 
 * @author Daniel Fern&aacute;ndez
 * 
 * @since 1.0
 *
 */
public class TemplateOutputException extends TemplateProcessingException {
    
    private static final long serialVersionUID = -247484715700490790L;

    
    public TemplateOutputException(final String message) {
        super(message);
    }
    
    public TemplateOutputException(final String message, final Throwable cause) {
        super(message, cause);
    }
    
    public TemplateOutputException(final String message, final String templateName, final Throwable cause) {
        super(message, templateName, cause);
    }

    public TemplateOutputException(final String message, final String templateName) {
        super(message, templateName);
    }
    
    
}

==> thymeleaf-3.0.9.RELEASE-sources.jar: org/thymeleaf/exceptions/TemplateOutputException.java <==
/*
 * =============================================================================
 * 
 *   Copyright (c) 2011-2016, The THYMELEAF team (http://www.thymeleaf.org)
 * 
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * 
 * =============================================================================
 */
package org.thymeleaf.exceptions;

/**
 * <p>
 *   Exception thrown by the template engine when a problem happens during template result output.
 * </p>
 * <p>
 *   Note a class with this name existed since 1.0, but it was completely reimplemented
 *   in Thymeleaf 3.0
 * </p>
 *
 * @author Daniel Fern&aacute;ndez
 * 
 * @since 3.0.0
 *
 */
public class TemplateOutputException extends TemplateProcessingException {
    
    private static final long serialVersionUID = -247484715700490790L;

    
    public TemplateOutputException(final String message, final String templateName, final int line, final int col, final Throwable cause) {
        super(message, templateName, line, col, cause);
    }

    
}
